@@ -28,6 +28,7 @@ import shutil
 from typing import Any, Callable
 
 import click
+from ansiblelint.prerun import prepare_environment
 from click_help_colors import HelpColorsCommand, HelpColorsGroup
 
 import molecule.scenarios
@@ -105,6 +106,11 @@ def execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args=()
         )
 
     for scenario in scenarios:
+
+        if scenario.config.config["prerun"]:
+            LOG.info("Performing prerun...")
+            prepare_environment()
+
         if command_args.get("subcommand") == "reset":
             LOG.info("Removing %s" % scenario.ephemeral_directory)
             shutil.rmtree(scenario.ephemeral_directory)
@@ -137,7 +143,7 @@ def execute_subcommand(config, subcommand):
     command = getattr(command_module, text.camelize(subcommand))
     # knowledge of the current action is used by some provisioners
     # to ensure they behave correctly during certain sequence steps,
-    # particulary the setting of ansible options in create/destroy,
+    # particularly the setting of ansible options in create/destroy,
     # and is also used for reporting in execute_cmdline_scenarios
     config.action = subcommand
 
