@@ -19,15 +19,17 @@
 #  DEALINGS IN THE SOFTWARE.
 """Test Command Module."""
 
+import logging
 import os
 
 import click
 
-from molecule import logger, util
+from molecule import util
 from molecule.api import drivers
 from molecule.command import base
+from molecule.config import DEFAULT_DRIVER
 
-LOG = logger.get_logger(__name__)
+LOG = logging.getLogger(__name__)
 MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
 
 
@@ -78,9 +80,9 @@ class Test(base.Base):
         Load an env file to read variables from when rendering
         molecule.yml.
 
-    .. program:: molecule --parallel test
+    .. program:: molecule test --parallel
 
-    .. option:: molecule --parallel test
+    .. option:: molecule test --parallel
 
        Run in parallelizable mode.
     """
@@ -108,7 +110,7 @@ class Test(base.Base):
     "--driver-name",
     "-d",
     type=click.Choice([str(s) for s in drivers()]),
-    help="Name of driver to use. (docker)",
+    help=f"Name of driver to use. ({DEFAULT_DRIVER})",
 )
 @click.option(
     "--all/--no-all",
